Struct SpansInfo
pub struct SpansInfo<T> { /* private fields */ }Trait Implementations
impl<T> NodeInfo for SpansInfo<T>where
T: Clone,
impl<T> NodeInfo for SpansInfo<T>where
T: Clone,
fn accumulate(&mut self, other: &SpansInfo<T>)
fn accumulate(&mut self, other: &SpansInfo<T>)
An operator that combines info from two subtrees. It is intended
(but not strictly enforced) that this operator be associative and
obey an identity property. In mathematical terms, the accumulate
method is the operation of a monoid.
fn compute_info(l: &SpansLeaf<T>) -> SpansInfo<T>
fn compute_info(l: &SpansLeaf<T>) -> SpansInfo<T>
A mapping from a leaf into the info type. It is intended (but
not strictly enforced) that applying the accumulate method to
the info derived from two leaves gives the same result as
deriving the info from the concatenation of the two leaves. In
mathematical terms, the compute_info method is a monoid
homomorphism.